from django.contrib import admin

from ..models.evaluation import EvaluationAttribute, Evaluation


class EvaluationAdmin(admin.ModelAdmin):
    list_display = ('evaluation_id', 'name', 'get_exercise_type')

    def get_exercise_type(self, obj):
        return obj.exercise_type.name


class EvaluationAttributeAdmin(admin.ModelAdmin):
    list_display = (
        'evaluation_attr_id', 'name', 'sex', 'age_min', 'age_max', 'value_min', 'value_max', 'evaluation_text')
    list_editable = ('name', 'sex', 'age_min', 'age_max', 'value_min', 'value_max', 'evaluation_text')
    list_filter = ('evaluation',)

    def copy_attributes(self, request, queryset):
        for objectAttr in reversed(queryset):
            objectAttr.pk = None
            objectAttr.name = objectAttr.name + "_copy"
            objectAttr.save()

    copy_attributes.short_description = "Clone the selected attribute"

    actions = [copy_attributes]


admin.site.register(Evaluation, EvaluationAdmin)
admin.site.register(EvaluationAttribute, EvaluationAttributeAdmin)
admin.autodiscover()
