from django.db import models
from django.utils.translation import ugettext_lazy as _
from ckeditor.fields import RichTextField

from .enums import LanguageTypes


class Description(models.Model):
    description_id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=50, help_text='Unique description name',
                            verbose_name=_("name"))
    description = RichTextField()
    version = models.IntegerField(blank=True)
    valid_from = models.DateTimeField(blank=True)
    valid_to = models.DateTimeField(blank=True)

    class Meta:
        db_table = 'description'
        verbose_name = _("Description")
        verbose_name_plural = _("Descriptions")

    def __str__(self):
        return self.name


class DescriptionTranslation(models.Model):
    translation_id = models.AutoField(primary_key=True)
    description = models.ForeignKey(Description, on_delete=models.CASCADE)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)
    description_translation = RichTextField()

    class Meta:
        db_table = 'description_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")
